import logging

db = {
    'host': '127.0.0.1',
    'port': 3306,
    'user': 'root',
    'password': 'password',
    'database': 'test',
    'charset': 'utf8',
    'debug': True
}

logging.basicConfig(level=logging.DEBUG)
